@@ -2,7 +2,7 @@ from __future__ import absolute_import
 from __future__ import unicode_literals
 import six
 from copy import deepcopy
-import unittest2
+import unittest
 from jsonobject import *
 from jsonobject.exceptions import (
     BadValueError,
@@ -68,7 +68,7 @@ class ObjectWithDictProperty(JsonObject):
     mapping = DictProperty()
 
 
-class JsonObjectTestCase(unittest2.TestCase):
+class JsonObjectTestCase(unittest.TestCase):
     def _danny_data(self):
         return {
             'first_name': 'Danny',
@@ -401,6 +401,14 @@ class JsonObjectTestCase(unittest2.TestCase):
         foo = Foo({'string_list': ['a', 'b', 'c']})
         self.assertEqual(foo.string_list, ['a', 'b' , 'c'])
 
+    def test_string_list_property_deepcopy(self):
+        class Foo(JsonObject):
+            strings = ListProperty(StringProperty)
+
+        foo = Foo(strings=['a', 'b', 'c'])
+        bar = Foo(strings=deepcopy(foo.strings))
+        self.assertEqual(bar.to_json(), {'strings': ['a', 'b', 'c']})
+
     def test_typed_dict_of_dict(self):
 
         class City(JsonObject):
@@ -434,7 +442,46 @@ class JsonObjectTestCase(unittest2.TestCase):
         self.assertIsInstance(foo.bar, Bar)
 
 
-class PropertyInsideContainerTest(unittest2.TestCase):
+class TestJsonArray(unittest.TestCase):
+
+    def test_init_with_list(self):
+        data = [1, 2, 3]
+        value = JsonArray(data, wrapper=None, type_config=self.type_config)
+        self.assertEqual(value, data)
+        self.assertIs(value._obj, data)
+
+    def test_init_with_none(self):
+        value = JsonArray(None, wrapper=None, type_config=self.type_config)
+        self.assertEqual(value, [])
+        self.assertEqual(value._obj, [])
+
+    def test_init_with_str(self):
+        with self.assertRaises(BadValueError):
+            JsonArray("abc", wrapper=None, type_config=self.type_config)
+
+    def test_single_arg_constructor_with_list(self):
+        data = [1, 2, 3]
+        value = JsonArray(data)
+        self.assertIs(value, data)
+
+    def test_single_arg_constructor_with_generator(self):
+        value = JsonArray(x for x in range(3))
+        self.assertEqual(value, [0, 1, 2])
+
+    def test_deep_copy(self):
+        data = [1, 2, 3]
+        array = JsonArray(data, wrapper=None, type_config=self.type_config)
+        value = deepcopy(array)
+        self.assertEqual(value, data)
+        self.assertEqual(value._obj, data)
+
+    @property
+    def type_config(self):
+        from jsonobject.base import TypeConfig
+        return TypeConfig(JsonObject.Meta.properties)
+
+
+class PropertyInsideContainerTest(unittest.TestCase):
 
     def test_default_is_required(self):
         class Foo(JsonObject):
@@ -466,7 +513,7 @@ class PropertyInsideContainerTest(unittest2.TestCase):
             Foo(container=[None])
 
 
-class LazyValidationTest(unittest2.TestCase):
+class LazyValidationTest(unittest.TestCase):
 
     def _validate_raises(self, foo):
         with self.assertRaises(BadValueError):
@@ -577,7 +624,7 @@ class LazyValidationTest(unittest2.TestCase):
         self._validate_not_raises(foo)
 
 
-class PropertyTestCase(unittest2.TestCase):
+class PropertyTestCase(unittest.TestCase):
     def test_date(self):
         import datetime
         p = DateProperty()
@@ -755,12 +802,12 @@ class PropertyTestCase(unittest2.TestCase):
         class Foo(JsonObject):
             pass
         foo = Foo()
-        
+
         with self.assertRaises(AttributeError):
             foo.hello
 
 
-class DynamicConversionTestCase(unittest2.TestCase):
+class DynamicConversionTestCase(unittest.TestCase):
     import datetime
 
     class Foo(JsonObject):
@@ -843,7 +890,7 @@ class User(JsonObject):
     tags = ListProperty(six.text_type)
 
 
-class TestExactDateTime(unittest2.TestCase):
+class TestExactDateTime(unittest.TestCase):
     def test_exact(self):
         class DateObj(JsonObject):
             date = DateTimeProperty(exact=True)
@@ -862,7 +909,7 @@ class TestExactDateTime(unittest2.TestCase):
         self.assertEqual(len(date_obj.to_json()['date']), 27)
 
 
-class IntegerTest(unittest2.TestCase):
+class IntegerTest(unittest.TestCase):
     @classmethod
     def setUpClass(cls):
         class Foo(JsonObject):
@@ -883,7 +930,7 @@ class IntegerTest(unittest2.TestCase):
         self.assertEqual(foo.to_json()['my_int'], 0)
 
 
-class TestReadmeExamples(unittest2.TestCase):
+class TestReadmeExamples(unittest.TestCase):
     def test(self):
         import datetime
         user1 = User(
